@@ -11,7 +11,7 @@ class Dynamo:
         self.utils = Utils()
         self.logger = Logger("DNX Dynamo =>")
 
-    def put_table_item(self, table, item, key, update=True):
+    def put_table_item(self, table, item, key, field_update="timestamp", update=True):
 
         self.logger.debug("Starting put_table_item")
         self.logger.debug(
@@ -32,7 +32,7 @@ class Dynamo:
         else:
             item_get = item
 
-        item_get.update({"timestamp": self.utils.date_time(milliseconds=True)})
+        item_get.update({field_update: self.utils.date_time(milliseconds=True)})
         table_db = dynamo_resource.Table(table)
         response = table_db.put_item(Item=item_get)
 
@@ -57,9 +57,8 @@ class Dynamo:
         response = table_db.get_item(Key=key)
 
         result = {}
-        Item = response.get("Item")
+        Item = response.get("Item", None)
         if Item is not None:
-            del Item['ResponseMetadata']
             for key, value in Item.items():
                 result.update({key: value})
 
@@ -85,7 +84,7 @@ class Dynamo:
         self.check_response(response)
 
         time.sleep(1)
-        self.logger.debug("Double check exclusion table")
+        self.logger.debug("Double check exclusion line table")
         item = self.get_item_table(table=table, key=key)
         if len(item) > 1:
             time.sleep(1)
