@@ -1,18 +1,23 @@
 import os
 
 LOG_LEVEL = os.getenv('LOG_LEVEL', 'INFO')
+
+DDB_STAGE_TRIGGER = os.getenv("DDB_STAGE_TRIGGER")
+DDB_STAGE = os.getenv("DDB_STAGE")
+DDB_STAGE_LOG = os.getenv("DDB_STAGE_LOG")
+DDB_STAGE_CONTROL_FILE_BINLOG = os.getenv("DDB_STAGE_CONTROL_FILE_BINLOG")
+DDB_CUSTOMER = os.getenv("DDB_CUSTOMER")
+DDB_CONFIG = os.getenv("DDB_CONFIG")
+
+DB_HOST_PATH = os.getenv("DB_HOST_PATH")
+DB_USER_PATH = os.getenv("DB_USER_PATH")
+DB_PASS_PATH = os.getenv("DB_PASS_PATH")
+
+GLUE_JOB_TRANSFORMER = os.getenv("GLUE_JOB_TRANSFORMER")
+
+LAMBDA_STREAMING_EXTRACTOR = os.getenv("LAMBDA_STREAMING_EXTRACTOR")
+
 S3_STAGING = os.getenv("S3_STAGING")
 S3_DATALAKE = os.getenv("S3_DATALAKE")
 S3_STAGING_PROCESSED = os.getenv("S3_STAGING_PROCESSED")
 S3_DATALAKE = os.getenv("S3_DATALAKE")
-DDB_STAGE_TRIGGER = os.getenv("DDB_STAGE_TRIGGER")
-DDB_STAGE_CONTROL = os.getenv("DDB_STAGE")
-DDB_STAGE_CONTROL_LOG = os.getenv("DDB_STAGE_LOG")
-DDB_STAGE_CONTROL_FILE_BINLOG = os.getenv("DDB_STAGE_CONTROL_FILE_BINLOG")
-DDB_CUSTOMER = os.getenv("DDB_CUSTOMER")
-DDB_CONFIG = os.getenv("DDB_CONFIG")
-#  TODO JOB_TRANSFORMER_GLUE = os.getenv()
-LAMBDA_STREAMING_EXTRACTOR = os.getenv("LAMBDA_STREAMING_EXTRACTOR")
-DB_HOST_PATH = os.getenv("DB_HOST_PATH")
-DB_USER_PATH = os.getenv("DB_USER_PATH")
-DB_PASS_PATH = os.getenv("DB_PASS_PATH")
